@@ -382,13 +382,11 @@ def insert_from_json(file_name: str, table_name: str, encoding='utf-8') -> int:
         return 0
 
 
-def truncate(table_name: str) -> int:
+def truncate_table(table_name: str) -> int:
     """ sqlexec.truncate('person') """
     return _execute(Dialect.get_truncate_sql(table_name))
 
 
-def drop(table_name: str) -> int:
+def drop_table(table_name: str) -> int:
     """ sqlexec.drop('person') """
-    return _execute('DROP TABLE %s' % table_name)
-
-
+    return _execute('DROP TABLE %s' % Dialect.get_dialect_str(table_name))
