@@ -33,7 +33,7 @@ class Loader:
         """
         try:
             import pandas as pd
-        except ModuleNotFoundError:
+        except:
             raise ModuleNotFoundError("No module named 'pandas', please install it use 'pip install pandas'")
 
         if self.description:
